BuildOhosResult class

Inheritance

Constructors

BuildOhosResult(String target, BuildConfig config)
BuildOhosResult.app(BuildConfig config)
factory
BuildOhosResult.hap(BuildConfig config)
factory

Properties

config BuildConfig
finalinherited
duration Duration?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
outputDirectory Directory
no setteroverride
outputFiles List<File>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited